pub fn resolve_runtime_approval(
canonical_spec_kv: &str,
env: Environment,
approval_credential: Option<&str>,
trusted_keys: &[TrustedApprovalKey],
) -> Result<ApprovalResolution, ApprovalVerificationError>Expand description
Resolve runtime approval presence by verifying an optional credential against the canonical spec hash, target environment, and required side-effect capabilities.